summaryrefslogtreecommitdiffstats
path: root/content/browser/speech/speech_recognizer_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/browser/speech/speech_recognizer_impl.h')
-rw-r--r--content/browser/speech/speech_recognizer_impl.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/content/browser/speech/speech_recognizer_impl.h b/content/browser/speech/speech_recognizer_impl.h
index 48196c3..e4b8756 100644
--- a/content/browser/speech/speech_recognizer_impl.h
+++ b/content/browser/speech/speech_recognizer_impl.h
@@ -84,8 +84,9 @@ class CONTENT_EXPORT SpeechRecognizerImpl
// Handles OnData in the IO thread. Takes ownership of |raw_audio|.
void HandleOnData(AudioChunk* raw_audio);
- // Helper method which closes the audio controller and blocks until done.
- void CloseAudioControllerSynchronously();
+ // Helper method which closes the audio controller and frees it asynchronously
+ // without blocking the IO thread.
+ void CloseAudioControllerAsynchronously();
void SetAudioManagerForTesting(AudioManager* audio_manager);